<?php {

  // Copyright(c) 2001-2003 Dino Co.,Ltd. All rights reserved.

  /*
   * Smarty plugin
   * ----------------------------------------
   * File:    function.dino_tpl_form.php
   * Id  :    $Id: function.dino_tpl_form.php,v 1.12 2003/10/28 14:19:14 sato_t Exp $
   * Type:    function
   * Name:    tpl_form
   * Purpose: ƥץ졼ˡtmpl_formǤФե४֥Ȥ
   * ---------------------------------------
   */

  /**
   * Smarty plugin: dino_tpl_form
   *
   * ƥץ졼ˡtmpl_formǤФե४֥Ȥ
   *
   * @package Dino_Tpl2
   * @access public
   */

  function smarty_function_dino_tpl_form($params, &$smarty) {
    /* 褳٤
       $t = $smarty->get_template_vars();
       $f = $t['__editform_obj'];
    */
    $form_name="none";
    if(strlen($params["form_name"])>0){
      $form_name=$params["form_name"];
    }
    $f =& $smarty->_tpl_vars['__form_obj'][$form_name];
    if($f) {
      if($params['type'] == 'start') {
	print $f->get_start();
	return;
      }
      if($params['type'] == 'finish') {
	print $f->get_finish();
	return;
      }

      $value = false;
      if (isset($params['value'])) {
	$value = (string)$params['value'];
      }

      $single = false;
      if (isset($params['single'])){
	$single = true;
      }

      if($params['type'] == 'group-begin') {
	if (isset($params['name'])){
	  $f->set_group_flag(true);
	  $f->set_now_group($params['name']);
	  $f->increment_counter($params['name']);
	} else{
	  //顼
	}
      }
      if($params['type'] == 'group-end') {
	$f->set_group_flag(false);
      }

      if ($params['status'] == 'frozen') {
	$f->freeze($params['name']);
      } elseif ($params['status'] == 'hidden') {
	$f->hide($params['name']);
      } elseif ($params['status'] == 'show') {
	$f->show($params['name']);
      } 
      $element=$f->get_element($params['name'], $value, $single);

      if($params['escape']=="html"){
	print htmlspecialchars($element);
      }else{
	print $element;
      }
    }
  }

} ?>
